@@ -34,6 +34,7 @@
 
 #define VMWGFX_NUM_DISPLAY_UNITS 8
 
+
 #define vmw_framebuffer_to_vfb(x) \
 	container_of(x, struct vmw_framebuffer, base)
 
@@ -52,6 +53,7 @@ struct vmw_framebuffer {
 	uint32_t user_handle;
 };
 
+
 #define vmw_crtc_to_du(x) \
 	container_of(x, struct vmw_display_unit, crtc)
 
@@ -68,6 +70,7 @@ int vmw_cursor_update_dmabuf(struct vmw_private *dev_priv,
 void vmw_cursor_update_position(struct vmw_private *dev_priv,
 				bool show, int x, int y);
 
+
 /**
  * Base class display unit.
  *
@@ -113,13 +116,15 @@ struct vmw_display_unit {
 #define vmw_connector_to_du(x) \
 	container_of(x, struct vmw_display_unit, connector)
 
+
 /*
  * Shared display unit functions - vmwgfx_kms.c
  */
 void vmw_display_unit_cleanup(struct vmw_display_unit *du);
 int vmw_du_page_flip(struct drm_crtc *crtc,
 		     struct drm_framebuffer *fb,
-		     struct drm_pending_vblank_event *event);
+		     struct drm_pending_vblank_event *event,
+		     uint32_t page_flip_flags);
 void vmw_du_crtc_save(struct drm_crtc *crtc);
 void vmw_du_crtc_restore(struct drm_crtc *crtc);
 void vmw_du_crtc_gamma_set(struct drm_crtc *crtc,
@@ -139,6 +144,7 @@ int vmw_du_connector_set_property(struct drm_connector *connector,
 				  struct drm_property *property,
 				  uint64_t val);
 
+
 /*
  * Legacy display unit functions - vmwgfx_ldu.c
  */
@@ -157,4 +163,5 @@ bool vmw_kms_screen_object_flippable(struct vmw_private *dev_priv,
 void vmw_kms_screen_object_update_implicit_fb(struct vmw_private *dev_priv,
 					      struct drm_crtc *crtc);
 
+
 #endif
