@@ -1,18 +1,34 @@
-#ifndef MY_ABC_HERE
-#define MY_ABC_HERE
-#endif
- 
+/* sound/soc/samsung/smartq_wm8987.c
+ *
+ * Copyright 2010 Maurus Cuelenaere <mcuelenaere@gmail.com>
+ *
+ * Based on smdk6410_wm8987.c
+ *     Copyright 2007 Wolfson Microelectronics PLC. - linux@wolfsonmicro.com
+ *     Graeme Gregory - graeme.gregory@wolfsonmicro.com
+ *
+ *  This program is free software; you can redistribute  it and/or modify it
+ *  under  the terms of  the GNU General  Public License as published by the
+ *  Free Software Foundation;  either version 2 of the  License, or (at your
+ *  option) any later version.
+ *
+ */
+
 #include <linux/gpio.h>
 #include <linux/module.h>
 
 #include <sound/soc.h>
 #include <sound/jack.h>
 
+#include <mach/gpio-samsung.h>
 #include <asm/mach-types.h>
 
 #include "i2s.h"
 #include "../codecs/wm8750.h"
 
+/*
+ * WM8987 is register compatible with WM8750, so using that as base driver.
+ */
+
 static struct snd_soc_card snd_soc_smartq;
 
 static int smartq_hifi_hw_params(struct snd_pcm_substream *substream,
@@ -40,28 +56,33 @@ static int smartq_hifi_hw_params(struct snd_pcm_substream *substream,
 		break;
 	}
 
+	/* set codec DAI configuration */
 	ret = snd_soc_dai_set_fmt(codec_dai, SND_SOC_DAIFMT_I2S |
 					     SND_SOC_DAIFMT_NB_NF |
 					     SND_SOC_DAIFMT_CBS_CFS);
 	if (ret < 0)
 		return ret;
 
+	/* set cpu DAI configuration */
 	ret = snd_soc_dai_set_fmt(cpu_dai, SND_SOC_DAIFMT_I2S |
 					   SND_SOC_DAIFMT_NB_NF |
 					   SND_SOC_DAIFMT_CBS_CFS);
 	if (ret < 0)
 		return ret;
 
+	/* Use PCLK for I2S signal generation */
 	ret = snd_soc_dai_set_sysclk(cpu_dai, SAMSUNG_I2S_RCLKSRC_0,
 					0, SND_SOC_CLOCK_IN);
 	if (ret < 0)
 		return ret;
 
+	/* Gate the RCLK output on PAD */
 	ret = snd_soc_dai_set_sysclk(cpu_dai, SAMSUNG_I2S_CDCLK,
 					0, SND_SOC_CLOCK_IN);
 	if (ret < 0)
 		return ret;
 
+	/* set the codec system clock for DAC and ADC */
 	ret = snd_soc_dai_set_sysclk(codec_dai, WM8750_SYSCLK, clk,
 				     SND_SOC_CLOCK_IN);
 	if (ret < 0)
@@ -70,6 +91,9 @@ static int smartq_hifi_hw_params(struct snd_pcm_substream *substream,
 	return 0;
 }
 
+/*
+ * SmartQ WM8987 HiFi DAI operations.
+ */
 static struct snd_soc_ops smartq_hifi_ops = {
 	.hw_params = smartq_hifi_hw_params,
 };
@@ -77,7 +101,7 @@ static struct snd_soc_ops smartq_hifi_ops = {
 static struct snd_soc_jack smartq_jack;
 
 static struct snd_soc_jack_pin smartq_jack_pins[] = {
-	 
+	/* Disable speaker when headphone is plugged in */
 	{
 		.pin	= "Internal Speaker",
 		.mask	= SND_JACK_HEADPHONE,
@@ -131,19 +155,18 @@ static int smartq_wm8987_init(struct snd_soc_pcm_runtime *rtd)
 	struct snd_soc_dapm_context *dapm = &codec->dapm;
 	int err = 0;
 
+	/* set endpoints to not connected */
 	snd_soc_dapm_nc_pin(dapm, "LINPUT1");
 	snd_soc_dapm_nc_pin(dapm, "RINPUT1");
 	snd_soc_dapm_nc_pin(dapm, "OUT3");
 	snd_soc_dapm_nc_pin(dapm, "ROUT1");
 
-#if defined(MY_DEF_HERE)
-	 
-#else  
+	/* set endpoints to default off mode */
 	snd_soc_dapm_enable_pin(dapm, "Internal Speaker");
 	snd_soc_dapm_enable_pin(dapm, "Internal Mic");
-#endif  
 	snd_soc_dapm_disable_pin(dapm, "Headphone Jack");
 
+	/* Headphone jack detection */
 	err = snd_soc_jack_new(codec, "Headphone Jack",
 			       SND_JACK_HEADPHONE, &smartq_jack);
 	if (err)
@@ -211,12 +234,14 @@ static int __init smartq_init(void)
 		return ret;
 	}
 
+	/* Initialise GPIOs used by amplifiers */
 	ret = gpio_request(S3C64XX_GPK(12), "amplifiers shutdown");
 	if (ret) {
 		dev_err(&smartq_snd_device->dev, "Failed to register GPK12\n");
 		goto err_unregister_device;
 	}
 
+	/* Disable amplifiers */
 	ret = gpio_direction_output(S3C64XX_GPK(12), 1);
 	if (ret) {
 		dev_err(&smartq_snd_device->dev, "Failed to configure GPK12\n");
@@ -245,6 +270,7 @@ static void __exit smartq_exit(void)
 module_init(smartq_init);
 module_exit(smartq_exit);
 
+/* Module information */
 MODULE_AUTHOR("Maurus Cuelenaere <mcuelenaere@gmail.com>");
 MODULE_DESCRIPTION("ALSA SoC SmartQ WM8987");
 MODULE_LICENSE("GPL");
